<?php
namespace app\controller;

use think\App;
use think\facade\View;
use app\model\Goods as GoodsModel;
use app\model\GoodsCategory as CategoryModel;

class Goods extends Base
{
    protected $model;

    public function __construct(App $app)
    {
        parent::__construct($app);
        $this->model = new GoodsModel();
    }

    public function index($key="")
    {
        $map = [];
        if ($key) {
            $map[] = ['name', 'LIKE', '%'.$key.'%'];
        }

        $limit = $this->request->cookie('limit') ? : 50;

        $list = $this->model->where($map)->paginate($limit);
        
        $page = $list->render();

        return View::fetch('',[
            'list' => $list,
            'key' => $key,
            'page' => $page,
            'limit' => $limit
        ]);
    }

    public function save()
    {
        $categoryModel = new CategoryModel();
        $categories = $categoryModel->column('name', 'id');
        if ($this->request->isPost()) {
            $param = $this->request->param();
            
            try {
                if ($param['id']) {
                    $seller = $this->model->find(intval($param['id']));
                } else {
                    $seller = new GoodsModel();
                    $seller->create_time = time();
                }
                $seller->name = $param['name'];
                $seller->price = $param['price'];
                $seller->category_id = $param['category_id'];
                $seller->category_name = $categories[$param['category_id']];
                
                $seller->save();
            } catch (\Exception $e) {
                $this->error($e->getMessage());
            }

            $this->success('操作成功', 'goods/index');
        } else {
            $id = $this->request->has('id','route') ? intval($this->request->param('id')) : 0;

            if ($id) {
                $data = $this->model->find($id);
            } else {
                $data = [
                    'id' => 0,
                    'name' => '',
                    'price' => 0.00,
                    'category_id' => 1,
                ];
            }

            return View::fetch('', [
                'data' => $data,
                'categories' => $categories
            ]);
        }
    }

    public function delete($id)
    {
        if ($this->model->destroy($id)) {
            return json(['code'=>2]);
        } else {
            return json(['code'=>0]);
        }
    }
}
